@@ -154,13 +154,27 @@ class Campaign(
         self,
         scope: constructs.Construct,
         id: builtins.str,
-        props: "ICampaign",
+        *,
+        collection_scheme: "CollectionScheme",
+        name: builtins.str,
+        signals: typing.Sequence["CampaignSignal"],
+        target: "Vehicle",
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param props: -
+        :param collection_scheme: 
+        :param name: 
+        :param signals: 
+        :param target: 
         '''
+        props = CampaignProps(
+            collection_scheme=collection_scheme,
+            name=name,
+            signals=signals,
+            target=target,
+        )
+
         jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
@@ -179,6 +193,74 @@ class Campaign(
         return typing.cast("Vehicle", jsii.get(self, "target"))
 
 
+@jsii.data_type(
+    jsii_type="cdk-aws-iotfleetwise.CampaignProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "collection_scheme": "collectionScheme",
+        "name": "name",
+        "signals": "signals",
+        "target": "target",
+    },
+)
+class CampaignProps:
+    def __init__(
+        self,
+        *,
+        collection_scheme: "CollectionScheme",
+        name: builtins.str,
+        signals: typing.Sequence["CampaignSignal"],
+        target: "Vehicle",
+    ) -> None:
+        '''
+        :param collection_scheme: 
+        :param name: 
+        :param signals: 
+        :param target: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "collection_scheme": collection_scheme,
+            "name": name,
+            "signals": signals,
+            "target": target,
+        }
+
+    @builtins.property
+    def collection_scheme(self) -> "CollectionScheme":
+        result = self._values.get("collection_scheme")
+        assert result is not None, "Required property 'collection_scheme' is missing"
+        return typing.cast("CollectionScheme", result)
+
+    @builtins.property
+    def name(self) -> builtins.str:
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def signals(self) -> typing.List["CampaignSignal"]:
+        result = self._values.get("signals")
+        assert result is not None, "Required property 'signals' is missing"
+        return typing.cast(typing.List["CampaignSignal"], result)
+
+    @builtins.property
+    def target(self) -> "Vehicle":
+        result = self._values.get("target")
+        assert result is not None, "Required property 'target' is missing"
+        return typing.cast("Vehicle", result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "CampaignProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class CampaignSignal(
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-aws-iotfleetwise.CampaignSignal",
@@ -233,13 +315,27 @@ class Fleet(
         self,
         scope: constructs.Construct,
         id: builtins.str,
-        props: "IFleet",
+        *,
+        fleet_id: builtins.str,
+        signal_catalog: "SignalCatalog",
+        description: typing.Optional[builtins.str] = None,
+        vehicles: typing.Optional[typing.Sequence["Vehicle"]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param props: -
+        :param fleet_id: 
+        :param signal_catalog: 
+        :param description: 
+        :param vehicles: 
         '''
+        props = FleetProps(
+            fleet_id=fleet_id,
+            signal_catalog=signal_catalog,
+            description=description,
+            vehicles=vehicles,
+        )
+
         jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
@@ -257,492 +353,79 @@ class Fleet(
     def signal_catalog(self) -> "SignalCatalog":
         return typing.cast("SignalCatalog", jsii.get(self, "signalCatalog"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vehicles")
-    def vehicles(self) -> typing.List["Vehicle"]:
-        return typing.cast(typing.List["Vehicle"], jsii.get(self, "vehicles"))
-
-
-@jsii.interface(jsii_type="cdk-aws-iotfleetwise.ICampaign")
-class ICampaign(typing_extensions.Protocol):
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="collectionScheme")
-    def collection_scheme(self) -> CollectionScheme:
-        ...
-
-    @collection_scheme.setter
-    def collection_scheme(self, value: CollectionScheme) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> builtins.str:
-        ...
-
-    @name.setter
-    def name(self, value: builtins.str) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signals")
-    def signals(self) -> typing.List[CampaignSignal]:
-        ...
-
-    @signals.setter
-    def signals(self, value: typing.List[CampaignSignal]) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="target")
-    def target(self) -> "Vehicle":
-        ...
-
-    @target.setter
-    def target(self, value: "Vehicle") -> None:
-        ...
-
-
-class _ICampaignProxy:
-    __jsii_type__: typing.ClassVar[str] = "cdk-aws-iotfleetwise.ICampaign"
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="collectionScheme")
-    def collection_scheme(self) -> CollectionScheme:
-        return typing.cast(CollectionScheme, jsii.get(self, "collectionScheme"))
-
-    @collection_scheme.setter
-    def collection_scheme(self, value: CollectionScheme) -> None:
-        jsii.set(self, "collectionScheme", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "name"))
-
-    @name.setter
-    def name(self, value: builtins.str) -> None:
-        jsii.set(self, "name", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signals")
-    def signals(self) -> typing.List[CampaignSignal]:
-        return typing.cast(typing.List[CampaignSignal], jsii.get(self, "signals"))
-
-    @signals.setter
-    def signals(self, value: typing.List[CampaignSignal]) -> None:
-        jsii.set(self, "signals", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="target")
-    def target(self) -> "Vehicle":
-        return typing.cast("Vehicle", jsii.get(self, "target"))
-
-    @target.setter
-    def target(self, value: "Vehicle") -> None:
-        jsii.set(self, "target", value)
-
-# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, ICampaign).__jsii_proxy_class__ = lambda : _ICampaignProxy
-
-
-@jsii.interface(jsii_type="cdk-aws-iotfleetwise.IFleet")
-class IFleet(typing_extensions.Protocol):
-    '''Interface.'''
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="fleetId")
-    def fleet_id(self) -> builtins.str:
-        ...
-
-    @fleet_id.setter
-    def fleet_id(self, value: builtins.str) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signalCatalog")
-    def signal_catalog(self) -> "SignalCatalog":
-        ...
-
-    @signal_catalog.setter
-    def signal_catalog(self, value: "SignalCatalog") -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[builtins.str]:
-        ...
-
-    @description.setter
-    def description(self, value: typing.Optional[builtins.str]) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vehicles")
-    def vehicles(self) -> typing.Optional[typing.List["Vehicle"]]:
-        ...
-
-    @vehicles.setter
-    def vehicles(self, value: typing.Optional[typing.List["Vehicle"]]) -> None:
-        ...
-
-
-class _IFleetProxy:
-    '''Interface.'''
-
-    __jsii_type__: typing.ClassVar[str] = "cdk-aws-iotfleetwise.IFleet"
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="fleetId")
-    def fleet_id(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "fleetId"))
-
-    @fleet_id.setter
-    def fleet_id(self, value: builtins.str) -> None:
-        jsii.set(self, "fleetId", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signalCatalog")
-    def signal_catalog(self) -> "SignalCatalog":
-        return typing.cast("SignalCatalog", jsii.get(self, "signalCatalog"))
-
-    @signal_catalog.setter
-    def signal_catalog(self, value: "SignalCatalog") -> None:
-        jsii.set(self, "signalCatalog", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[builtins.str]:
-        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
-
-    @description.setter
-    def description(self, value: typing.Optional[builtins.str]) -> None:
-        jsii.set(self, "description", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vehicles")
     def vehicles(self) -> typing.Optional[typing.List["Vehicle"]]:
         return typing.cast(typing.Optional[typing.List["Vehicle"]], jsii.get(self, "vehicles"))
 
-    @vehicles.setter
-    def vehicles(self, value: typing.Optional[typing.List["Vehicle"]]) -> None:
-        jsii.set(self, "vehicles", value)
 
-# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, IFleet).__jsii_proxy_class__ = lambda : _IFleetProxy
-
-
-@jsii.interface(jsii_type="cdk-aws-iotfleetwise.IServiceCatalogProps")
-class IServiceCatalogProps(typing_extensions.Protocol):
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="database")
-    def database(self) -> aws_cdk.aws_timestream.CfnDatabase:
-        ...
-
-    @database.setter
-    def database(self, value: aws_cdk.aws_timestream.CfnDatabase) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="nodes")
-    def nodes(self) -> typing.List["SignalCatalogNode"]:
-        ...
-
-    @nodes.setter
-    def nodes(self, value: typing.List["SignalCatalogNode"]) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="role")
-    def role(self) -> aws_cdk.aws_iam.Role:
-        ...
-
-    @role.setter
-    def role(self, value: aws_cdk.aws_iam.Role) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="table")
-    def table(self) -> aws_cdk.aws_timestream.CfnTable:
-        ...
-
-    @table.setter
-    def table(self, value: aws_cdk.aws_timestream.CfnTable) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[builtins.str]:
-        ...
-
-    @description.setter
-    def description(self, value: typing.Optional[builtins.str]) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[builtins.str]:
-        ...
-
-    @name.setter
-    def name(self, value: typing.Optional[builtins.str]) -> None:
-        ...
-
-
-class _IServiceCatalogPropsProxy:
-    __jsii_type__: typing.ClassVar[str] = "cdk-aws-iotfleetwise.IServiceCatalogProps"
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="database")
-    def database(self) -> aws_cdk.aws_timestream.CfnDatabase:
-        return typing.cast(aws_cdk.aws_timestream.CfnDatabase, jsii.get(self, "database"))
-
-    @database.setter
-    def database(self, value: aws_cdk.aws_timestream.CfnDatabase) -> None:
-        jsii.set(self, "database", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="nodes")
-    def nodes(self) -> typing.List["SignalCatalogNode"]:
-        return typing.cast(typing.List["SignalCatalogNode"], jsii.get(self, "nodes"))
-
-    @nodes.setter
-    def nodes(self, value: typing.List["SignalCatalogNode"]) -> None:
-        jsii.set(self, "nodes", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="role")
-    def role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "role"))
-
-    @role.setter
-    def role(self, value: aws_cdk.aws_iam.Role) -> None:
-        jsii.set(self, "role", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="table")
-    def table(self) -> aws_cdk.aws_timestream.CfnTable:
-        return typing.cast(aws_cdk.aws_timestream.CfnTable, jsii.get(self, "table"))
-
-    @table.setter
-    def table(self, value: aws_cdk.aws_timestream.CfnTable) -> None:
-        jsii.set(self, "table", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[builtins.str]:
-        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
-
-    @description.setter
-    def description(self, value: typing.Optional[builtins.str]) -> None:
-        jsii.set(self, "description", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[builtins.str]:
-        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))
-
-    @name.setter
-    def name(self, value: typing.Optional[builtins.str]) -> None:
-        jsii.set(self, "name", value)
-
-# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, IServiceCatalogProps).__jsii_proxy_class__ = lambda : _IServiceCatalogPropsProxy
-
-
-@jsii.interface(jsii_type="cdk-aws-iotfleetwise.IVehicle")
-class IVehicle(typing_extensions.Protocol):
-    '''Interface.'''
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="createIotThing")
-    def create_iot_thing(self) -> builtins.bool:
-        ...
-
-    @create_iot_thing.setter
-    def create_iot_thing(self, value: builtins.bool) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vehicleId")
-    def vehicle_id(self) -> builtins.str:
-        ...
-
-    @vehicle_id.setter
-    def vehicle_id(self, value: builtins.str) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vehicleModel")
-    def vehicle_model(self) -> "VehicleModel":
-        ...
-
-    @vehicle_model.setter
-    def vehicle_model(self, value: "VehicleModel") -> None:
-        ...
-
-
-class _IVehicleProxy:
-    '''Interface.'''
-
-    __jsii_type__: typing.ClassVar[str] = "cdk-aws-iotfleetwise.IVehicle"
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="createIotThing")
-    def create_iot_thing(self) -> builtins.bool:
-        return typing.cast(builtins.bool, jsii.get(self, "createIotThing"))
-
-    @create_iot_thing.setter
-    def create_iot_thing(self, value: builtins.bool) -> None:
-        jsii.set(self, "createIotThing", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vehicleId")
-    def vehicle_id(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "vehicleId"))
-
-    @vehicle_id.setter
-    def vehicle_id(self, value: builtins.str) -> None:
-        jsii.set(self, "vehicleId", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vehicleModel")
-    def vehicle_model(self) -> "VehicleModel":
-        return typing.cast("VehicleModel", jsii.get(self, "vehicleModel"))
-
-    @vehicle_model.setter
-    def vehicle_model(self, value: "VehicleModel") -> None:
-        jsii.set(self, "vehicleModel", value)
-
-# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, IVehicle).__jsii_proxy_class__ = lambda : _IVehicleProxy
-
-
-@jsii.interface(jsii_type="cdk-aws-iotfleetwise.IVehicleModel")
-class IVehicleModel(typing_extensions.Protocol):
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> builtins.str:
-        ...
-
-    @name.setter
-    def name(self, value: builtins.str) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="networkInterfaces")
-    def network_interfaces(self) -> typing.List["VehicleInterface"]:
-        ...
-
-    @network_interfaces.setter
-    def network_interfaces(self, value: typing.List["VehicleInterface"]) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signalCatalog")
-    def signal_catalog(self) -> "SignalCatalog":
-        ...
-
-    @signal_catalog.setter
-    def signal_catalog(self, value: "SignalCatalog") -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[builtins.str]:
-        ...
-
-    @description.setter
-    def description(self, value: typing.Optional[builtins.str]) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="networkFileDefinitions")
-    def network_file_definitions(
+@jsii.data_type(
+    jsii_type="cdk-aws-iotfleetwise.FleetProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "fleet_id": "fleetId",
+        "signal_catalog": "signalCatalog",
+        "description": "description",
+        "vehicles": "vehicles",
+    },
+)
+class FleetProps:
+    def __init__(
         self,
-    ) -> typing.Optional[typing.List["NetworkFileDefinition"]]:
-        ...
-
-    @network_file_definitions.setter
-    def network_file_definitions(
-        self,
-        value: typing.Optional[typing.List["NetworkFileDefinition"]],
+        *,
+        fleet_id: builtins.str,
+        signal_catalog: "SignalCatalog",
+        description: typing.Optional[builtins.str] = None,
+        vehicles: typing.Optional[typing.Sequence["Vehicle"]] = None,
     ) -> None:
-        ...
+        '''Interface.
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signals")
-    def signals(self) -> typing.Optional[typing.List["VehicleSignal"]]:
-        ...
+        :param fleet_id: 
+        :param signal_catalog: 
+        :param description: 
+        :param vehicles: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "fleet_id": fleet_id,
+            "signal_catalog": signal_catalog,
+        }
+        if description is not None:
+            self._values["description"] = description
+        if vehicles is not None:
+            self._values["vehicles"] = vehicles
 
-    @signals.setter
-    def signals(self, value: typing.Optional[typing.List["VehicleSignal"]]) -> None:
-        ...
+    @builtins.property
+    def fleet_id(self) -> builtins.str:
+        result = self._values.get("fleet_id")
+        assert result is not None, "Required property 'fleet_id' is missing"
+        return typing.cast(builtins.str, result)
 
-
-class _IVehicleModelProxy:
-    __jsii_type__: typing.ClassVar[str] = "cdk-aws-iotfleetwise.IVehicleModel"
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "name"))
-
-    @name.setter
-    def name(self, value: builtins.str) -> None:
-        jsii.set(self, "name", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="networkInterfaces")
-    def network_interfaces(self) -> typing.List["VehicleInterface"]:
-        return typing.cast(typing.List["VehicleInterface"], jsii.get(self, "networkInterfaces"))
-
-    @network_interfaces.setter
-    def network_interfaces(self, value: typing.List["VehicleInterface"]) -> None:
-        jsii.set(self, "networkInterfaces", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signalCatalog")
+    @builtins.property
     def signal_catalog(self) -> "SignalCatalog":
-        return typing.cast("SignalCatalog", jsii.get(self, "signalCatalog"))
+        result = self._values.get("signal_catalog")
+        assert result is not None, "Required property 'signal_catalog' is missing"
+        return typing.cast("SignalCatalog", result)
 
-    @signal_catalog.setter
-    def signal_catalog(self, value: "SignalCatalog") -> None:
-        jsii.set(self, "signalCatalog", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="description")
+    @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
-        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
+        result = self._values.get("description")
+        return typing.cast(typing.Optional[builtins.str], result)
 
-    @description.setter
-    def description(self, value: typing.Optional[builtins.str]) -> None:
-        jsii.set(self, "description", value)
+    @builtins.property
+    def vehicles(self) -> typing.Optional[typing.List["Vehicle"]]:
+        result = self._values.get("vehicles")
+        return typing.cast(typing.Optional[typing.List["Vehicle"]], result)
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="networkFileDefinitions")
-    def network_file_definitions(
-        self,
-    ) -> typing.Optional[typing.List["NetworkFileDefinition"]]:
-        return typing.cast(typing.Optional[typing.List["NetworkFileDefinition"]], jsii.get(self, "networkFileDefinitions"))
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    @network_file_definitions.setter
-    def network_file_definitions(
-        self,
-        value: typing.Optional[typing.List["NetworkFileDefinition"]],
-    ) -> None:
-        jsii.set(self, "networkFileDefinitions", value)
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signals")
-    def signals(self) -> typing.Optional[typing.List["VehicleSignal"]]:
-        return typing.cast(typing.Optional[typing.List["VehicleSignal"]], jsii.get(self, "signals"))
-
-    @signals.setter
-    def signals(self, value: typing.Optional[typing.List["VehicleSignal"]]) -> None:
-        jsii.set(self, "signals", value)
-
-# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, IVehicleModel).__jsii_proxy_class__ = lambda : _IVehicleModelProxy
+    def __repr__(self) -> str:
+        return "FleetProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 class NetworkFileDefinition(
@@ -780,13 +463,33 @@ class SignalCatalog(
         self,
         scope: constructs.Construct,
         id: builtins.str,
-        props: IServiceCatalogProps,
+        *,
+        database: aws_cdk.aws_timestream.CfnDatabase,
+        nodes: typing.Sequence["SignalCatalogNode"],
+        role: aws_cdk.aws_iam.Role,
+        table: aws_cdk.aws_timestream.CfnTable,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param props: -
+        :param database: 
+        :param nodes: 
+        :param role: 
+        :param table: 
+        :param description: 
+        :param name: 
         '''
+        props = SignalCatalogProps(
+            database=database,
+            nodes=nodes,
+            role=role,
+            table=table,
+            description=description,
+            name=name,
+        )
+
         jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
@@ -837,6 +540,94 @@ class SignalCatalogNode(
         jsii.set(self, "node", value)
 
 
+@jsii.data_type(
+    jsii_type="cdk-aws-iotfleetwise.SignalCatalogProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "database": "database",
+        "nodes": "nodes",
+        "role": "role",
+        "table": "table",
+        "description": "description",
+        "name": "name",
+    },
+)
+class SignalCatalogProps:
+    def __init__(
+        self,
+        *,
+        database: aws_cdk.aws_timestream.CfnDatabase,
+        nodes: typing.Sequence[SignalCatalogNode],
+        role: aws_cdk.aws_iam.Role,
+        table: aws_cdk.aws_timestream.CfnTable,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param database: 
+        :param nodes: 
+        :param role: 
+        :param table: 
+        :param description: 
+        :param name: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "database": database,
+            "nodes": nodes,
+            "role": role,
+            "table": table,
+        }
+        if description is not None:
+            self._values["description"] = description
+        if name is not None:
+            self._values["name"] = name
+
+    @builtins.property
+    def database(self) -> aws_cdk.aws_timestream.CfnDatabase:
+        result = self._values.get("database")
+        assert result is not None, "Required property 'database' is missing"
+        return typing.cast(aws_cdk.aws_timestream.CfnDatabase, result)
+
+    @builtins.property
+    def nodes(self) -> typing.List[SignalCatalogNode]:
+        result = self._values.get("nodes")
+        assert result is not None, "Required property 'nodes' is missing"
+        return typing.cast(typing.List[SignalCatalogNode], result)
+
+    @builtins.property
+    def role(self) -> aws_cdk.aws_iam.Role:
+        result = self._values.get("role")
+        assert result is not None, "Required property 'role' is missing"
+        return typing.cast(aws_cdk.aws_iam.Role, result)
+
+    @builtins.property
+    def table(self) -> aws_cdk.aws_timestream.CfnTable:
+        result = self._values.get("table")
+        assert result is not None, "Required property 'table' is missing"
+        return typing.cast(aws_cdk.aws_timestream.CfnTable, result)
+
+    @builtins.property
+    def description(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("description")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def name(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "SignalCatalogProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class SignalCatalogSensor(
     SignalCatalogNode,
     metaclass=jsii.JSIIMeta,
@@ -887,13 +678,24 @@ class Vehicle(
         self,
         scope: constructs.Construct,
         id: builtins.str,
-        props: IVehicle,
+        *,
+        create_iot_thing: builtins.bool,
+        vehicle_id: builtins.str,
+        vehicle_model: "VehicleModel",
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param props: -
+        :param create_iot_thing: 
+        :param vehicle_id: 
+        :param vehicle_model: 
         '''
+        props = VehicleProps(
+            create_iot_thing=create_iot_thing,
+            vehicle_id=vehicle_id,
+            vehicle_model=vehicle_model,
+        )
+
         jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
@@ -967,13 +769,33 @@ class VehicleModel(
         self,
         scope: constructs.Construct,
         id: builtins.str,
-        props: IVehicleModel,
+        *,
+        name: builtins.str,
+        network_interfaces: typing.Sequence[VehicleInterface],
+        signal_catalog: SignalCatalog,
+        description: typing.Optional[builtins.str] = None,
+        network_file_definitions: typing.Optional[typing.Sequence[NetworkFileDefinition]] = None,
+        signals: typing.Optional[typing.Sequence["VehicleSignal"]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param props: -
+        :param name: 
+        :param network_interfaces: 
+        :param signal_catalog: 
+        :param description: 
+        :param network_file_definitions: 
+        :param signals: 
         '''
+        props = VehicleModelProps(
+            name=name,
+            network_interfaces=network_interfaces,
+            signal_catalog=signal_catalog,
+            description=description,
+            network_file_definitions=network_file_definitions,
+            signals=signals,
+        )
+
         jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
@@ -986,10 +808,154 @@ class VehicleModel(
     def signal_catalog(self) -> SignalCatalog:
         return typing.cast(SignalCatalog, jsii.get(self, "signalCatalog"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="description")
+
+@jsii.data_type(
+    jsii_type="cdk-aws-iotfleetwise.VehicleModelProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "name": "name",
+        "network_interfaces": "networkInterfaces",
+        "signal_catalog": "signalCatalog",
+        "description": "description",
+        "network_file_definitions": "networkFileDefinitions",
+        "signals": "signals",
+    },
+)
+class VehicleModelProps:
+    def __init__(
+        self,
+        *,
+        name: builtins.str,
+        network_interfaces: typing.Sequence[VehicleInterface],
+        signal_catalog: SignalCatalog,
+        description: typing.Optional[builtins.str] = None,
+        network_file_definitions: typing.Optional[typing.Sequence[NetworkFileDefinition]] = None,
+        signals: typing.Optional[typing.Sequence["VehicleSignal"]] = None,
+    ) -> None:
+        '''
+        :param name: 
+        :param network_interfaces: 
+        :param signal_catalog: 
+        :param description: 
+        :param network_file_definitions: 
+        :param signals: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "name": name,
+            "network_interfaces": network_interfaces,
+            "signal_catalog": signal_catalog,
+        }
+        if description is not None:
+            self._values["description"] = description
+        if network_file_definitions is not None:
+            self._values["network_file_definitions"] = network_file_definitions
+        if signals is not None:
+            self._values["signals"] = signals
+
+    @builtins.property
+    def name(self) -> builtins.str:
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def network_interfaces(self) -> typing.List[VehicleInterface]:
+        result = self._values.get("network_interfaces")
+        assert result is not None, "Required property 'network_interfaces' is missing"
+        return typing.cast(typing.List[VehicleInterface], result)
+
+    @builtins.property
+    def signal_catalog(self) -> SignalCatalog:
+        result = self._values.get("signal_catalog")
+        assert result is not None, "Required property 'signal_catalog' is missing"
+        return typing.cast(SignalCatalog, result)
+
+    @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
-        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
+        result = self._values.get("description")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def network_file_definitions(
+        self,
+    ) -> typing.Optional[typing.List[NetworkFileDefinition]]:
+        result = self._values.get("network_file_definitions")
+        return typing.cast(typing.Optional[typing.List[NetworkFileDefinition]], result)
+
+    @builtins.property
+    def signals(self) -> typing.Optional[typing.List["VehicleSignal"]]:
+        result = self._values.get("signals")
+        return typing.cast(typing.Optional[typing.List["VehicleSignal"]], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "VehicleModelProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+@jsii.data_type(
+    jsii_type="cdk-aws-iotfleetwise.VehicleProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "create_iot_thing": "createIotThing",
+        "vehicle_id": "vehicleId",
+        "vehicle_model": "vehicleModel",
+    },
+)
+class VehicleProps:
+    def __init__(
+        self,
+        *,
+        create_iot_thing: builtins.bool,
+        vehicle_id: builtins.str,
+        vehicle_model: VehicleModel,
+    ) -> None:
+        '''Interface.
+
+        :param create_iot_thing: 
+        :param vehicle_id: 
+        :param vehicle_model: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "create_iot_thing": create_iot_thing,
+            "vehicle_id": vehicle_id,
+            "vehicle_model": vehicle_model,
+        }
+
+    @builtins.property
+    def create_iot_thing(self) -> builtins.bool:
+        result = self._values.get("create_iot_thing")
+        assert result is not None, "Required property 'create_iot_thing' is missing"
+        return typing.cast(builtins.bool, result)
+
+    @builtins.property
+    def vehicle_id(self) -> builtins.str:
+        result = self._values.get("vehicle_id")
+        assert result is not None, "Required property 'vehicle_id' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def vehicle_model(self) -> VehicleModel:
+        result = self._values.get("vehicle_model")
+        assert result is not None, "Required property 'vehicle_model' is missing"
+        return typing.cast(VehicleModel, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "VehicleProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 class VehicleSignal(
@@ -1099,26 +1065,26 @@ class SignalCatalogBranch(
 
 __all__ = [
     "Campaign",
+    "CampaignProps",
     "CampaignSignal",
     "CanDefinition",
     "CanVehicleInterface",
     "CanVehicleSignal",
     "CollectionScheme",
     "Fleet",
-    "ICampaign",
-    "IFleet",
-    "IServiceCatalogProps",
-    "IVehicle",
-    "IVehicleModel",
+    "FleetProps",
     "NetworkFileDefinition",
     "SignalCatalog",
     "SignalCatalogBranch",
     "SignalCatalogNode",
+    "SignalCatalogProps",
     "SignalCatalogSensor",
     "TimeBasedCollectionScheme",
     "Vehicle",
     "VehicleInterface",
     "VehicleModel",
+    "VehicleModelProps",
+    "VehicleProps",
     "VehicleSignal",
 ]
 
